"use strict";
this.name = "SpaceBarFaceLift";
this.author = "phkb";
this.description = "Looks after external dock for spacebar";
this.version = "1.0";
this.copyright = "2024 phkb";
this.license = "CC BY-NC-SA 4.0";

this._addDock = false;
this._externalDockNotification = false;
this._timer = null;
this._setStation = null;

//----------------------------------------------------------------------------------------
this.systemWillPopulate = function() {
    this._addDock = true;
    this._setStation = null;
}

//----------------------------------------------------------------------------------------
this.systemWillRepopulate = function() {
    if (this._addDock == true && system.countShipsWithRole("random_hits_any_spacebar") > 0) {
        this._addDock = false;
        // there should only be 1 spacebar in any system
        var sp = system.shipsWithRole("random_hits_any_spacebar")[0];
        if (sp) this.$registerExternalDocks(sp);
    }
}

//----------------------------------------------------------------------------------------
// registers our external docks with the eds
this.$registerExternalDocks = function (station) {
	var eds = worldScripts.ExternalDockSystem;
    if (eds) {
        this._setStation = station;

        // set up the timer to let the player know about the docks
        this._timer = new Timer(this, this.$externalDockNotification, 2, 2);

        eds.$addExternalDock({station:station, position:[-550, 0, 22], scale:0.5, preDockCallback:this.$preDockSetup.bind(this)});
    } else {
        // get rid of the flashers on the external dock
        var fa = station.flashers;
        var last = fa.length;
        while (last--) {
            fa[last].remove();
            if (last == 10) break;
        }
    }
}

//----------------------------------------------------------------------------------------
this.$preDockSetup = function(station) {
    // docking at the external port will still get you transferred inside
    player.addMessageToArrivalReport(expandDescription("[spacebar_redocked]"));
}

//----------------------------------------------------------------------------------------
this.$externalDockNotification = function $externalDockNotification() {
	if (this._setStation && this._externalDockNotification == false) {
		if (this._setStation.position.distanceTo(player.ship) < player.ship.scannerRange * 0.85) {
			this._setStation.commsMessage(expandDescription("[spacebar_external_dock]"), player.ship);
			this._externalDockNotification = true;
		}
	} else {
		this._timer.stop();
	}
}
